@@ -33,7 +33,7 @@ const { EventsRuleToLambdaProps, EventsRuleToLambda } = require('@aws-solutions-
 
 const props: EventsRuleToLambdaProps = {
     lambdaFunctionProps: {
-        code: lambda.Code.asset(`${__dirname}/lambda`),
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_12_X,
         handler: 'index.handler'
     },
